@@ -441,10 +441,10 @@ gpk_dbus_install_provide_files (GpkDbus *dbus, guint32 xid, gchar **files, const
 }
 
 /**
- * gpk_dbus_remove_package_by_file:
+ * gpk_dbus_remove_package_by_files:
  **/
 void
-gpk_dbus_remove_package_by_file (GpkDbus *dbus, guint32 xid, gchar **files, const gchar *interaction, DBusGMethodInvocation *context)
+gpk_dbus_remove_package_by_files (GpkDbus *dbus, guint32 xid, gchar **files, const gchar *interaction, DBusGMethodInvocation *context)
 {
 	GpkDbusTask *task;
 	task = gpk_dbus_create_task (dbus, xid, interaction, context);
@@ -506,6 +506,17 @@ gpk_dbus_install_gstreamer_resources (GpkDbus *dbus, guint32 xid, gchar **resour
 	gpk_dbus_task_install_gstreamer_resources (task, resources, (GpkDbusTaskFinishedCb) gpk_dbus_task_finished_cb, dbus);
 }
 
+/**
+ * gpk_dbus_install_resources:
+ **/
+void
+gpk_dbus_install_resources (GpkDbus *dbus, guint32 xid, const gchar *type, gchar **resources, const gchar *interaction, DBusGMethodInvocation *context)
+{
+	GpkDbusTask *task;
+	task = gpk_dbus_create_task (dbus, xid, interaction, context);
+	gpk_dbus_task_install_resources (task, pk_provides_enum_from_string (type), resources, (GpkDbusTaskFinishedCb) gpk_dbus_task_finished_cb, dbus);
+}
+
 /**
  * gpk_dbus_install_printer_drivers:
  **/
