@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -28,11 +28,10 @@
 #include <packagekit-glib2/packagekit.h>
 #include <dbus/dbus-glib.h>
 
-#include "egg-debug.h"
-
 #include "gpk-common.h"
 #include "gpk-error.h"
 #include "gpk-dbus.h"
+#include "gpk-debug.h"
 
 /**
  * main:
@@ -70,7 +69,7 @@ main (int argc, char *argv[])
 	context = g_option_context_new ("gpk-install-catalog");
 	g_option_context_set_summary (context, _("Catalog Installer"));
 	g_option_context_add_main_entries (context, options, NULL);
-	g_option_context_add_group (context, egg_debug_get_option_group ());
+	g_option_context_add_group (context, gpk_debug_get_option_group ());
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	g_option_context_parse (context, &argc, &argv, NULL);
 	g_option_context_free (context);
@@ -90,7 +89,7 @@ main (int argc, char *argv[])
 	/* check dbus connections, exit if not valid */
 	connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
 	if (connection == NULL) {
-		egg_warning ("%s", error->message);
+		g_warning ("%s", error->message);
 		goto out;
 	}
 
@@ -100,7 +99,7 @@ main (int argc, char *argv[])
 					   "/org/freedesktop/PackageKit",
 					   "org.freedesktop.PackageKit.Modify");
 	if (proxy == NULL) {
-		egg_warning ("Cannot connect to session service");
+		g_warning ("Cannot connect to session service");
 		goto out;
 	}
 
@@ -120,7 +119,7 @@ main (int argc, char *argv[])
 				  /* TRANSLATORS: we don't have anything more useful to translate. sorry. */
 				  _("The request failed. More details are available in the detailed report."),
 				  error->message);
-		egg_warning ("%i: %s", error->code, error->message);
+		g_warning ("%i: %s", error->code, error->message);
 		goto out;
 	}
 out:
